SdkgenHttpClient class

Constructors

SdkgenHttpClient(String baseUrl, Client? client, Map<String, Object> typeTable, Map<String, FunctionDescription> fnTable, Map<String, SdkgenErrorDescription> errTable)

Properties

baseUrl → Uri
final
deviceId ↔ String?
getter/setter pair
errTable → Map<String, SdkgenErrorDescription>
final
extra → Json
final
fnTable → Map<String, FunctionDescription>
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
interceptors → List<SdkgenInterceptors>
final
random → Random
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeTable → Map<String, Object>
final

Methods

addInterceptor(SdkgenInterceptors interceptor) → SdkgenHttpClient
makeRequest(String functionName, Map<String, Object?> args) → Future<Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited