StructTypeDescription class

Constructors

StructTypeDescription(Type type, Map<String, String> fields, Function createFromFields, Function exportAsMap)

Properties

createFromFields ↔ Function
getter/setter pair
exportAsMap ↔ Function
getter/setter pair
fields ↔ Map<String, String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ Type
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited